@@ -103,7 +103,7 @@ class VerifyToken:
             data = s.loads(token.encode('utf-8'))
         except:
             handle_abnormal(
-                message='来自 {0} 的 Token 验证失败'.format(request.remote_addr),
+                message='来自 {0} 的 Token 验证失败'.format(request.environ.get('HTTP_X_REAL_IP', request.remote_addr)),
                 status=401,
             )
         toke_uid = data.get('id')  # token中传来的
